changeset 93246:6ac54c43b7ca

(lm-with-file): Use mode and syntax table for Emacs Lisp, not Lisp.
author Johan Bockgård <bojohan@gnu.org>
date Wed, 26 Mar 2008 14:13:06 +0000
parents 3bbc1c7cc289
children 5fc9c77f2aea
files lisp/ChangeLog lisp/emacs-lisp/lisp-mnt.el
diffstat 2 files changed, 10 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Wed Mar 26 12:24:37 2008 +0000
+++ b/lisp/ChangeLog	Wed Mar 26 14:13:06 2008 +0000
@@ -1,3 +1,8 @@
+2008-03-26  Johan Bockg$(Q)[(Brd  <bojohan@gnu.org>
+
+	* emacs-lisp/lisp-mnt.el (lm-with-file): Use mode and syntax table
+	for Emacs Lisp, not Lisp.
+
 2008-03-26  Juanma Barranquero  <lekktu@gmail.com>
 
 	* emacs-lisp/bytecomp.el (byte-compile-obsolete): If no
--- a/lisp/emacs-lisp/lisp-mnt.el	Wed Mar 26 12:24:37 2008 +0000
+++ b/lisp/emacs-lisp/lisp-mnt.el	Wed Mar 26 14:13:06 2008 +0000
@@ -37,7 +37,8 @@
 ;; Another entry point automatically addresses bug mail to a package's
 ;; maintainer or author.
 
 ;; This file can be loaded by your lisp-mode-hook.  Have it (require 'lisp-mnt)
 
 ;; This file is an example of the header conventions.  Note the following
 ;; features:
@@ -305,12 +306,12 @@
        (if ,filesym
 	   (with-temp-buffer
 	     (insert-file-contents ,filesym)
-	     (lisp-mode)
+	     (emacs-lisp-mode)
 	     ,@body)
 	 (save-excursion
 	   ;; Switching major modes is too drastic, so just switch
-	   ;; temporarily to the Lisp mode syntax table.
-	   (with-syntax-table lisp-mode-syntax-table
+	   ;; temporarily to the Emacs Lisp mode syntax table.
+	   (with-syntax-table emacs-lisp-mode-syntax-table
 	     ,@body))))))
 
 (put 'lm-with-file 'lisp-indent-function 1)
@@ -37,7 +37,8 @@
 ;; maintainer or author.
 
-;; This file can be loaded by your lisp-mode-hook.  Have it (require 'lisp-mnt)
+;; This file can be loaded by your emacs-lisp-mode-hook.  Have it
+;; (require 'lisp-mnt)
 
 ;; This file is an example of the header conventions.  Note the following